# Chapter Four: Action <a name="action"></a>
Drama depends heavy on the chance of failure, the following chapter deals will
how to handle all actions in Autonomous Garden.

## Dice rolling <a name="diceRolling"></a>
Unless specifically mentioned otherwise, all dice rolls are resolved in the
manner explained here.

A number of standard 6 sided dice are rolled. When two or more dice are rolled
simultaneously, their results are not added together. Instead, the highest
value rolled is considered to be the outcome of the die roll.

The totals of die rolls are often influenced by modifiers, such as Attributes
or situation modifiers. Modifiers are added to the total of a die roll. If
negative modifiers lower the total below zero, the final result is zero.

**Critical rolls** happen when more than one of any number is rolled, each
extra number adds +1 to the total. This has no other effect on the outcome of
the roll.

**Fumbles** happen when all dice rolled come up 1s, in addition to the low
result the character also suffers a mishap such as the character slipping,
pulling a muscle, dropping something etc.

### Skill Rolls <a name="skillRolls"></a>
The Skill roll is the most common form of Action test in the game. Roll a
number of dice equal to the skill level, if the skill level is 0 roll two dice
taking the lowest result. These will usually be formating like this *Skill
Name + Attribute Name* indicating what skill is to be rolled and what attribute to
add to the result, other modifiers maybe be added but are not listed.

### Attribute Roll <a name="attributeRolls"></a>
An attribute test is less common than a skill roll relying on innate ability
instead of learned. Attribute Rolls assume innate proficiency and are rolled
with *2 dice + Attribute*.

### Margin of Success <a name="MoS"></a>
How well a character beats a Target Number, ether set by the GM or the result
of an opposed roll is called the Margin of Success. An attack with a higher MoS
will deal more damage, a wealth roll will deplete less funds, etc.

**Advantage and Complications:** Sometimes the test fails but provides
something useful anyway, and sometimes an test succeeds but has a draw back, these are advantage

**Advantage:** Usually happens when the test fails but provides something
useful anyway.

**Complication:** Usually happens when the test succeeds but things don't go so
well.

MoS | Success
:---: | ---
>= 3 | Yes and an advantage
+2 | Yes
+1 | Yes but a complication
 0 | Maybe but at a cost
-1 | No but an advantage
-2 | No
<= -3 | No and a complication

On each bonus or complication the GM chooses one of the following.

+ **Detail** gain more or less detailed information.
+ **Situational** the GM adds something relevant to the situation.
+ **Time** +/- 25% time to finish an extended action test.

**Succeed at a Cost:** If the roll is tied the GM can offer the player to
succeed at a cost. This allows the player to treat the MoS as 1 but there is a
downside similar to fumbling. Or the player can choose to fail the test.

### Taking Average<a name="takingAverage"></a>
Whenever a character is not being rushed or threatened, they can treat the
final result of a test as *2 + Skill level* rather than roll, attributes and
modifiers aren't added. This allows characters to be successful at routine
tasks with enough skill.

### Accumulated Success <a name="accumulatedSuccess"></a>
Sometimes a task will require time and effort to complete, when this happens
the task has an additional MoS requirement to fully complete. Each sucess adds
towards the task and failure subtracts until the Mos is met.

This rule is useful when a character is trying to pick a lock while a guard is
coming, influence an NPC into changing their beliefs, or even rebuilding a
vehicle.

## Action Tests <a name="actionTests"></a>

### Unopposed Tests <a name="unopposedActionTests"></a>
An unopposed action tests consist of a die roll whose result is compared to a
fixed difficulty value called a Target Number; a higher Target Number indicates
a more difficult situation.

TN | Description
:---: | ---
1 | Effortless
2 | Very Easy
3 | Easy
4 | Moderate
5 | Challenging
6 | Difficult
7 | Very Difficult
9 | Extremely Difficult
11 | Near Impossible
14+ | Pray for Divine Intervention!

### Opposed Tests <a name="opposedActionTests"></a>
Whenever two individuals oppose each other's actions, they make an opposed
action tests. Each opponent makes an action tests using the appropriate skill
and attribute, and are compared to each other to determine success.


## Actions and time<a name="actionTypes"></a>
Most of the time characters can do things without needing any rules to govern
them, open a door, pick fruit, ride a bike etc with the Moderator loosely
tracking time. However during an action round many things are happening at once
and are broken up into different types of actions.

During an action round, each character gets one major action but can take
additional actions at a penalty to all major actions they make during their
turn.

**Minor Actions:** Don't require much time or concentration. They don't take an
action and don't usually require a test.  
Examples include: talking, dropping something held, defending oneself in
combat, basic perception, and opening a door.

**Major Actions:** These actions take a second or more to complete and usually
require concentration.  
Example include: picking something up, getting something from a pack or pocket,
attacking, moving, opening a locked door.

**Extended Actions:** These are actions that take at least a full turn to do
and usually require an action test. The duration can be in turns, minutes, or
days. For durations of days or more it is assume that 8 hours is devoted to the
task, which can be adjusted based on [MoS](#MoS).  
Examples include: repairing, gardening, searching a room, etc.

### Special Actions <a name="specialAction"></a>

**Assist:** Characters an help other characters out on a skill test. To do so
the character(s) must have at at least 1 rank in the skill, and be able to
communicate and work together to provide the bonus.

Group Size | Mod
--- | :---:
2-4 | +1
5-8 | +2
9-16 | +3
17-32 | +4

**Ready:** Characters can react to something outside of their turn, interrupting
another character's actions when a specified event happens. The Readied
character gets to take their readied action right after the specified event.

Characters can remained readied for as long as they wish, but if the specified
event doesn't occur they lose that action.

### Acting Fast <a name="actingFast"></a>
Sometimes characters need to do an extended action and there isn't enough time.
Characters can take a penality to the test to reduce the time required for an
extended action.

Mod | Time required
:---: | ---
-1 | 1/2
-2 | 1/4
-3 | 1/8
-4 | 1/16

## Movement <a name="movement"></a>
Each turn characters can take various movement based actions. The movement can
be split up as needed to perform other actions.

Each character has 3 movement rates, one for walking, one for running, and one
of all out sprint. While movement takes an action to perform, action penalties
for melee and unarmed attacks should be ignored as this tends to break
believability.

Because moving makes one a harder target each movement speed also applies its
action penalty as a bonus to defense tests(sprinting counts as +3), and
movement based athletics tests.

**Walking:** This is the characters standard movement speed when not in a
hurry. Walking is a [minor action](#actions).

**Running:** The character moves quickly but still allow for other actions to
be taken or to travel longer distances. Running counts as 2 [minor
actions](#actions).

**Sprinting:** The character spends the whole round moving as fast as possible.
This is an [extended action](#actions).

### Swimming
Swimming works a lot like walking except that it is slower and more dangerous.
Unless they have a swimming movement characters move at 1/4th their standard
rates and can walk thru shallow water at 1/2.

Staying afloat while swimming is a [minor action](#actions). While swimming
against a current takes a [major action](#actions) and an *Athletics +
Body* test.

**Acting in water:** Characters performing actions use the appropriate skill or
athletics whichever is lower. Encumbrance penalties while swimming are doubled.

### Carrying Capacity
Characters movement is limited by how much they carry, their maximum capacity
is the same as the deadlift for their [Body](#body). Treat objects which aren't
designed to be easily carried with straps, handles, etc as double their weight.
Objects which require balance and attention when carried apply a -1 action
penalty, -2 for two handed objects.

Capacity | Max Movement
--- | ---
1/2 | Sprint
3/4 | Run
Max | walk

### Chase Scenes
Chase scenes are a common element which allows for action without necessarily
being life threatening. Each round, the characters on foot or in [muscle powered
vehicles](#vehciles) make an *Athletics + Body* Test and add the result to their speed
for the round. On a fumble characters loose 1d6 meters for the round.

Characters can choose to go over obstacles to try to lose their pursuers. When
this happens both parties make another *Athletics + Body* test, the winner
adds their MoS to their speed. Fumbles causes a crash, and the character looses
a round recovering.

TN | Obstacle
--- | ---
2 | Low fence
4 | Bench, garbage bins
6 | Tall fence

### Falls
Whenever a character falls they take damage equal to 1 for ever 3 meters
fallen(max of dv 10) x impact surface x 2 dice taking the highest.

The character can roll *Athletics + Agility* and subtract the result from the
number of meters fallen before calculating damage. If the result is higher than
the distance fallen they land on their feet.

If the character is dropped on their head or fumbles their athletics test, half
their wounds thresholds for damage.

Impact Surface | Multiplier
--- | ---
Concrete | x2
Grass or dirt | x1
Sand or shallow water | x0.5
Deep water | x0.25
Crash pads | x0.1

### Jumping
To jump, a character must make an *Athletics + Body* test, and the defensive
modifier of the character’s current movement. The horizontal distance jumped is
MoS x 0.75 meters. Vertical distance is MoS x 0.25 in meters.

TN | Surface
:---: | ---
3 | Standard
6 | Rough
10 | Slippery
14 | Climbing

## Social Actions <a name="socialActions"></a>
Player characters can attempt to persuade NPCs into doing something they want.
This is an opposed roll with [Accumulative Success](#accumulatedSuccess) equal
to Dispotion + NPCs Psyche + Requst modifiers.

Characters can only attempt to make progress on their request once per scene,
however they may also change their request and use their current MoS against
the new request.

**Disposition:** Describes how much an NPC likes another character. Initial
disposition usually only ranges form unfriendly to friendly. Tho other factors
may effect this.

Antagonistic or hostile NPCs will not willingly help, but their disposition can
be improved or intimidated. Cooperative and supportive NPCs will fulfill
simple/beneficial requests without needing a test.

**Request:** The nature of the request will also effect how an NPC reacts, if
it effects them or someone they care about it is more likely to be denied. Some
requests are are so far out of character that the NPC will just reject them
outright.

**Social requests Modifiers**
Situation | MoS
--- | :---:
**NPC Dispostion** |
Hostile | 6
Antagonistic | 5
Unfriendly | 4
Indifferent | 3
Friendly | 2
Cooperative | 1
Supportive | 0
**Request** |
Simple/short | -1
Complex/long | +1
Violates NPC's values | +2
Beneficial to NPC | -3
Dangerous to NPC | +3

### Influencing disposition
Sometimes characters will want to change the dispotion of a character. To do
this the character will need to spend some time with the NPC, at least a scene,
and make an opposed test influence them, usually *Negotiation + Charisma* vs
*Negotion + Psyche*. If sucessful the NPC's disposition changes by one
stage, a fumble causes the dispotion to go in the undisired direction.

## Resolving Combat <a name="resolvingCombat"></a>
Many stories will involve some form of combat, an exciting high-speed chase, a
shootout or a grand showdown. There is nothing quite as a satisfying as finally
defeating the antagonist in a climactic battle. The game organizes combat
around 6 second rounds, the order is determined by initiative and ends when
everyone has taken their turn, and a new round begins.

### Initiative <a name="initiative"></a>
Initiative determines who acts first in a combat round. At the beginning of
each turn, players will declare their intent for the turn. This will determine
who acts first in initiative.

1. Close actions that don't require moving first
2. Ranged actions
3. All other close actions

If necessary, combatants can roll opposed *Awareness + Perception* tests highest
roll goes first.

### Surprise <a name="surprise"></a>
Surprise occurs when a character attempts to affect an unwary target. The
target makes an Opposed *Awareness + Perception* test against the attacker's
*Stealth + Agility*. Success means the target notices the attacker and can take
defensive actions; this can sometimes happen long before the attacker was ready
to attack.

Attacking unwary targets requires the attacker to pass a standard (not Opposed)
Skill test with a Target Number number of 1 + the defender’s [combat
modifiers](#combatModifiers).

### Attacking <a name="attacking"></a>
Attacking is a [major action](#actionTypes) opposed by the target's
[defense](#defending). The skill and attribute rolled depend on the type of
attack being used:
+ Unarmed: *Unarmed + Body*
+ Melee: *Melee + Agility*
+ Ranged: *Firearms + Perception*
+ Thrown: *Athletics + Perception*
+ Explosives: *Mechanics + Logic*

### Defending <a name="defending"></a>
Unless the target is surprised or incapacitated somehow, the defender makes a
*Defense + Agility* test against attacks. Defending is a [minor
action](#actionTypes).

Objects, locations, and unaware targets all have a defense of 1 + [Combat
Modifers](#combatModifiers) against attacks. This assumes a human sized target,
if smaller use the [Aiming Rules](#aiming)

#### Special Defense Actions

##### Parry
The defender can block melee, thrown, and unarmed attacks using a melee weapon.
Instead of a usual defense test, the defender can roll *Melee + Agility*.

Unarmed defenders can parry against unarmed attacks, they make an *Unarmed +
Agility* test for their defense.

##### Dodge
The character spends the full round defending themself, All defense rolls gain
a +3 bonus until their next turn.

### Multiple actions in combat<a name="multipleActions"></a>
It is assumed that character get one major or minor action per turn. However if
characters want then can take multiple actions in a round then can do so at the
cost of a -1 penalty per additional action to all [major action](#actionTypes) tests.
Multiple actions must be declared at the beginning of the round.

### Special Attack Actions

#### Aiming <a name="aiming"></a>
Characters can aim at specific body parts to increase damage or get around
armor. Characters take a -1 to thier attack but the range they can make the
attack is limited based on the location.

Critical wounds to limbs do not kill the target, but instead sever or
obliterate the limb.

Burst fire attacks have too much recoil to be aimed at specific hit locations.

Location Size | Distance | Wound Levels
--- | --- | ---
Torso | Long | x1
Limb | Medium | x1
Head | Medium | x0.5
Eye/Finger | Short | x0.5

#### Deception Attacks
An attacker in melee or unarmed combat uses feints and dirty tricks, decreasing
the skill level of both their attack roll and the defender's defense rolls by a
specified amount. If the defender’s dice are reduced to zero, they roll as if
unskilled.

#### Lining Up a Shot <a name="liningUpAShot"></a>
A character can spend a few combat rounds steadying their aim to improve their
odds to hit. Add one die to the attacker’s roll per combat round spent aiming,
up to a maximum equal to the shooter’s Skill level. The character may not move
while lining up a shot.

### Combat Modifiers <a name="combatModifiers"></a>
The following modifiers apply to an attacker’s attempt to hit or affect a
target.

Situation | Attack Mod | Defense Mod | Example
--- | :---: | :---: | ---
**COVER** | | | |
light cover | 0 | +1 | Foliage, furniture, thin walls
Heavy cover | 0 | +3 | Rocks, motor vehicles, think walls
Fully hidden | -2 | +1\* | Only weapon is visible
**LIGHTING** | | |
Very bright | -1 | -1 | -1 | Spotlight, tactical light
Dim | -1 | -1 | Moonlight
Poor | -2 | -2 | Starlight, fog or smoke
Barely lit | -3 | -3 | Lighter, indirect light, heavy fog
Pitch black | -4 | -4 | No light at all
**SITUATION** | | |
Flanking | 0 | -1 | Attacker behind and to side
Behind | 0 | -2 | Attacker directly behind
Multiple attackers | 0 | -1 | Per additional attacker after the first
Offhand | -1 | N/A | Using non dominate hand
**PERCEPTIVE RANGE** | | | |
Medium range | -1 | N/A | Within a dozen meters, 2x weapon range
Long range | -2 | N/A | Within fifty meters, 4x weapon range
Extreme range | -3 | N/A | Within a hundred meters, 8x weapon range

\* Fully hidden behind heavy cover prevents defender from being hit

#### Range
Weapons can only be used within a specific range. Weapons list their short
range, medium range is 2x short, long range is 4x short range, and extreme
range is 8x short.

Thrown range is equal to 6 + Body - item's weight(in kilograms rounded up).

#### Special Circumstances

**Close Quarters:** When fighting or acting in a small space or one full of
inconvenient obstacles (e.g. in a tight corridor or a dense forest), powerful
blows and actions that involve large items are more difficult. Any action done
with the help of a piece of equipment longer than the character’s arm is at -1.
Some items are so cumbersome that they either cannot be used at all or deserve
a higher penalty (e.g. a bull-whip).

**Multiple Attackers:** When several people are attacking a single defendant,
that defendant gets penalties to their Defense and Parry rolls. The defender
suffers a -1 penalty for all attacks from a second attacker, -2 for those from
a third attackers and -3 for those from any additional attackers. A single
attacker who takes multiple actions in a round does not count as two attackers
for these purposes.

### Injuries <a name="injuries"></a>
Characters can take two types of physical damage. Hand to hand combat and low
impact trauma cause bruises. Weapons and collisions cause wounds. Both types of
damage are recorded on the character's wound track.

#### Damage
If an attacker hits an opponent, they deal an amount of damage equal to their
weapon’s Damage Value times the Margin of Success of the attack, up to a MoS of
6.

#### Wound Thresholds
Any time a character takes damage it is compared to their Wound Levels. If the
damage is lower than their Flesh Wound, they receive only minor scrapes or
bruises that are not worth tracking in game but do cause some paint to the
character.

**Flesh:** Hurt but probably wont kill. Such as cracked ribs, deep cuts,
bleeding bruises etc.

**Deep:** Are potentially life threatening. They're composed of broken bones,
punctured organs, and severe concussions.

**Critical Wound:** Are instantly fatal. They compose blown off heads,
decapitation, cut in half etc.

**Critical Bruises:** Knock the character out for 1d6 hours and fill up the
remaining bruise track.

#### Wound Track
The wound track keeps record of the kinds and severity of wounds. There are 2
rows of boxes one for each type of damage.

Regardless of the damage type wounds are marked by putting a single slash
across a box for a flesh round or across 2 boxes for deep wounds.

Once a character's wound track is filled up they begin to bleed out and must be
stabilized within 10 minutes or die.

Once the character's bruise track is filled up they will begin to take wounds
instead.

##### Wound Penalties
Wounds impair a characters ability to act. This penalty is applied to all
attribute and skill tests a character makes as well as to medicine test by
other characters to treat them.

Wounded characters also find it difficult to move from pain reducing their
maximum movement rate.

Wound | Penalty | additional effect
--- | :---: | ---
**Wound** | |
Flesh | -1 | Can't sprint
Deep | -2 | Can't run, 2x wound can't stand
**Bruise** |
Flesh | -1/2
Deep | -1

#### Wound Degeneration
If a wound is left untreated it will continue to bleed, become infected, and
cause additional trauma, unless it is stabilized. Bruises do not degenerate.

The character needs to make a **Body test TN 1**, failing the test means the
wound worsens, causing an additional flesh wound. On a fumble the character
gains a deep wound. Each type of wound is tested independently of each other,
flesh wounds are tested every 24 hours divided by number of flesh wounds. Deep
wounds are tested every hour divided by number of deep wounds.

#### Stabilizing Wounds
To prevent wound degeneration, needs to spend 5 minutes an pass a *Medicine +
Logic TN 1* test modified by the patient's Body, and wound and bruise
penalties. Success stabilizes one wound, failure wastes time, and a fumble
wastes time and cause an additional flesh wound.

Once a wound is stabilized it will not degenerate but can become destabilized
again. Flesh wounds destabilize from heavy activities such as combat or
running. Deep wounds destabilize more easily, anything more than bed rest,
eating, and bathing.

### Recovery from Injuries <a name="recovery"></a>
Once a character is wounded they will need to recover. Characters will need
medical care to cure their wounds fully, while bruises heal on their own. Only
one injury heals at a time, flesh wounds heal before deep wounds and
resuscitated characters must spend a week recovering before their wounds begin
to heal.

Injury | Time
--- | ---
**Bruises** |
Flesh | 1d6 hours
Deep | 1d6 days
**Wounds** |
Aided Flesh | 3 days
Aided Deep | 2 weeks
Unaided Flesh | 1 week
Unaided Deep | 1 Month

**Unaided:** is when the wound receives only minimal treatment such as bandages
or a splint. Deep ones inflect a -1 penalty to physical actions until the
character makes it thru rehabilitation. A Comatose character will not survive
more than a week without medical aid.

**Aided:** is when the wound receives treatment and rehabilitation from a
medical hospital. Comatose characters can survive indefinitely on life support.

## Hazards <a name="hazards"></a>
Outside of combat there are a number of general hazards characters can face.

### Asphyxiation
The average adult can hold their breath for two minutes before blacking out.
For every 30 seconds after the fist minute the character needs to make a
Body test vs TN 2, each 30 seconds apply a -1 penalty to the test. If the
character is doing strenuous activity 1/2 all times.

Asphyxiation is a terrifying experience which usually leads to panic.
Characters need to make a Psyche test vs TN 3 or panic. Panicking characters
will need to make additional Psyche tests TN 3 to perform any action other
than saving themselves.

### Disease
when a character comes into contact with a disease they need to make a Body test

**Virulence:** How strong a disease is. When exposed characters make a Body
test against this value. Failure means the character contracts the illness.

**Onset Time:** The longest interval before the substance takes effect. The
time it takes to take effect is onset time divided by MoS. Fumbled results
take effect in 1/10th the listed onset time.

**Effect:** The symptoms that the character experiences when exposed.

#### Influenza
**Virulence:** 9
**Onset Time:** One Week
Airborne illness.

MoS | Effect
--- | ---
>= 0 | Sore thought and runny noise. Lasts for 4 - MoS days
<= -1 | Aches, cough, and congestion, action penalty equal to MoS, reduces by 1 per day
<= -5 | Incapacitated for MoS + 6 days, afterwards treat as MoS -4
Fumble | Incapacitated with life threatening fever for a week, Roll 1d6 every
day, with medical aid the character dies on a 1, without aid they die on a 1 or
2/. Treat as MoS of -8 once fever breaks.

### Fire
Fire automatically deals 2 dice x DV damage from a full round of exposure, less
than a full round the DV is halved, and on a fumble the DV is also halved.

DV | Source
:---: | ---
0 | Lighter, Match
1 | Campfire, Torch, Flare
2 | Bonfire, Chemical fire, Inferno

On a deep wound the character is incapacitated for 1d6 rounds as they thrash
about in agony.

#### Vehicles and Fire
If a vehicle tries to pass thru burning terrain they must make make a **Pilot +
Agility** test TN 3x the DV of the fire. Failure is treated as an attack with
the same MoS.

### Electricity
Electricity will deal 2 dice x DV from a full round of exposure, less than a
full round the DV is halved, and on a fumbled the DV is also halved.

DV | Source
:---: | ---
1 | Wall outlet
2 | Power lines
4 | Power mains
5 | Small lightning strike
10 | Large lightning strike
20 | Hydroelectric dam generator

Characters who receive a flesh wound are locally paralyzed as their muscles
clench up uncontrollability from contact. Characters who receive a deep wound
are fully paralyzed and may suffer a heart attack.

Regardless of the type of wound characters must also make a Body test TN 5x the
DV.

MoS | Effect
:---: | ---
<= -1 | Character is knocked out
<= -5 | Character slips into a coma
Fumble | Instant death

### Radiation
Characters accumulate ionizing radiation in the form of Decigrays, 1/10th the
standard measurement of radiation. Once a day, whenever a character's decigray
total increases past 7 they will need to make a body test. Radiation causes
both an immediate effect and a long term illness, but only one test is need for
both effects. If they succeed they will have only minor effects such as red
itchy skin.

Characters who are able to be treated before their long term effects start at a
modern medical facility gain a +2 on their Body tests.

While radiation accumulation is somewhat permanent characters purge 1 decigray
every 2 week to a minimum of 1/10th the highest accumulated total.

Decigray Total | Target Number | Onset Time | Illness
--- | :---: | :---: | ---
>= 7 | 6 | - | -
>= 10 | 8 | 8 weeks | Mild leukopenia, fatigue, weakness, -1 action penalty
>= 20 | 12 | 6 weeks | Moderate leukopenia, hemorrgae, infections, alocpecia, -2 action penalty
>= 60 | 14 | 4 weeks | Severe leukopenia, high fever, diarrhea, vomiting, dizziness, hypotension, electrolyte disturbance, -3 action penalty
>= 80 | 16 | 2 weeks | Nausea, vomiting, sever diarrhea, high fever, electrolyte disturbance, shock, -4 action penalty
>= 300 | 18 | 2 days | Death

**Immediate effects:** In the short term radiation poisoning causes fatigue,
fever, headaches, lack of appetite, nausea, reddening of skin, and vomiting.

MoS | Effect
:---: | ---
<= -1 | Action penalty equal to MoS(max -4) after Body roll hours, reduce by 1 ever 12 hours
<= -10 | Death in 8/MoS weeks
Fumble | Death in 2 weeks

**Radiation Sources**
Radiation Source | Decigray/rate
--- | :---:
Nuclear reactor meltdown | 1-5/minute
Solar flare | 0-3
Kiloton air burst at 1 km | 10
**Megaton air burst** |
at 2 km | 600
at 10 km | 50
at 25 | 10
**Fallout from megaton ground burst at ground zero** |
after 1 hour | 30/hour
after 2 hour | 12/hour
after 6 hour | 3/hour
after 1 day | 1/hour

#### Protection
Protection is measured in a Radiation Shielding Factor. This number effectively
divides the amount of radiation a character receives.

RSF | Source
:---: | ---
1.5 | Unprotected vehicle
15 | Typical house
40 | Public Fallout shelter


## Magick <a name="magick"></a>
Magicians have the ability to cause change in the world, where this comes from
or if it's the magician doing it all doesn't really matter to the magician.
Magick works, how it works is less important, tho many magicians will likely
have a view as to how.

The following is a non exhaustive list of magickal abilities and how to use
them. This list describes the spells common to mortals, organized by their
discipline.

### Astralmancy
Astralmancy is the practice of manipulating ones consciousness and the [Astral
plane](#astralPlane).

**Entropomancy:** moves sets of events to be in favor of completing a specified
task. The caster makes an *Astralmancy + Psyche* test TN 5. This allows for a
mundane event or synchronistic event to occur that helps the goal of the spell.

**Shield:** creates a barrier that completely covers it's target. The caster
makes an *Astralmancy + Psyche* test TN 3. The target gains a +2 to defensive
rolls against spells and spirit attacks for the scene.

**Ward:** creates a magical wall against spells and spirits. The caster
makes an *Astralmancy + Psyche* test TN 4. The wall works like a physical wall
except it doesn't stop perception.

### Divination
Divination is the attempt to gain insight into a question or situation by way
of an occultic, standardized process or ritual. Used in various forms
throughout history, diviners ascertain their interpretations of how a querent
should proceed by reading signs, events, or omens, or through alleged contact
with a paranormal agency.

**Remote Viewing:** the caster "views" a target via non local senses. The caster
makes an *Divination + Intuition* test TN 5. The amount of information gathered
is determined by the MoS of the spell.

MoS | Information
:---: | ---
1 | Vague information
2 | Basic information
3 | Detailed information
4 | Secret information
5 | Unknown information

**Scrying:** by using a Focus(Map and pendulum, dowsing rod, etc...) the caster
learns the location of the target. The caster makes an *Divination + Intuition*
test TN 3. The accuracy of information gathered is determined by the MoS of the
spell.

MoS | Information
:---: | ---
1 | Vague information
2 | Basic information
3 | Detailed information
4 | Secret information
5 | Unknown information

### Evocation
Evocation is the practice of calling upon spirits. Comparable practices exist
in many religions and magical traditions and may employ the use of
mind-altering substances with and without uttered word formulas.

**Banish:** forces a spirit out of the area for a scene. The caster makes an
*Evocation + Psyche* test opposed by Psyche.

**Invocate:** the caster allows themself to become partially possessed. The
caster makes an *Evocation + Psyche* test TN 5. The caster gains an additional
level in a specific skill for the scene.

**Summon:** calls for a spirit to appear before the caster. The caster makes an
*Evocation + Psyche* test TN 5. Once the spirit appears they may be asked to
perform actions for the caster.

### Restoration
Restoration is the practice of manipulating the body(Energy, cells, etc...) to
heal wounds.

**Bolster:** The caster enhances the target's immune system to counter an
aliment. The caster makes a *Restoration + Psyche* test TN 5. The
target gains a +2 bonus against the aliment.

**Dispel:** damages the target of an ongoing spell equal to MoS. The caster
makes a *Restoration + Psyche* vs *Psyche* of the spells caster. Once the spell
takes more than 5 points of damage it's effect is completely ended.

**Harm:** deals damage with DV 1 + Psyche. The caster makes a *Restoration +
Psyche* vs the targets *Psyche*.

**Heal:** the target is treated for traumatic experiences and can heal after a
month of rest. The caster makes a *Restoration + Psyche* TN 1. The caster makes
the test with the target's action penalties.

**Regenerate:** The target's heals wounds 25% faster than normal for a week.
The caster makes a *Restoration + Psyche* test TN 4. This effect is additive
with other healing rate modifiers.

